@@ -1,21 +1,19 @@
-
 import sys
-
 import itertools
-
 import decimal
 import datetime
 import uuid
 import pyrfc3339
-
 from .edn_lex import Keyword, Symbol
 from .edn_parse import TaggedElement
 
+
 if sys.version_info[0] == 3:
     long = int
     basestring = str
     unicode = str
 
+
 def dump(obj):
     def seq(obj):
         return " ".join([dump(i) for i in obj])
@@ -50,4 +48,5 @@ def dump(obj):
     elif isinstance(obj, TaggedElement):
         return str(obj)
     else:
-        raise NotImplementedError("Don't know how to handle {} : {}", type(obj), obj)
+        raise NotImplementedError(
+            "Don't know how to handle {} : {}", type(obj), obj)
